@@ -1,19 +1,21 @@
 """Intrinio Cash Flow Statement Model."""
 
-import warnings
-from typing import Any, Dict, List, Literal, Optional
+# pylint: disable=unused-argument
 
+from typing import Any, Dict, List, Literal, Optional
+from warnings import warn
+
+from openbb_core.app.model.abstract.error import OpenBBError
 from openbb_core.provider.abstract.fetcher import Fetcher
 from openbb_core.provider.standard_models.cash_flow import (
     CashFlowStatementData,
     CashFlowStatementQueryParams,
 )
+from openbb_core.provider.utils.descriptions import QUERY_DESCRIPTIONS
 from openbb_core.provider.utils.helpers import ClientResponse, amake_requests
 from openbb_intrinio.utils.helpers import get_data_one
 from pydantic import Field, field_validator, model_validator
 
-_warn = warnings.warn
-
 
 class IntrinioCashFlowStatementQueryParams(CashFlowStatementQueryParams):
     """Intrinio Cash Flow Statement Query.
@@ -22,7 +24,16 @@ class IntrinioCashFlowStatementQueryParams(CashFlowStatementQueryParams):
     Source: https://docs.intrinio.com/documentation/web_api/get_fundamental_standardized_financials_v2
     """
 
-    period: Literal["annual", "quarter", "ttm", "ytd"] = Field(default="annual")
+    __json_schema_extra__ = {
+        "period": {
+            "choices": ["annual", "quarter", "ttm", "ytd"],
+        }
+    }
+
+    period: Literal["annual", "quarter", "ttm", "ytd"] = Field(
+        default="annual",
+        description=QUERY_DESCRIPTIONS.get("period", ""),
+    )
     fiscal_year: Optional[int] = Field(
         default=None,
         description="The specific fiscal year.  Reports do not go beyond 2008.",
@@ -84,6 +95,16 @@ class IntrinioCashFlowStatementData(CashFlowStatementData):
         "sale_of_property_plant_and_equipment": "saleofplantpropertyandequipment",
     }
 
+    reported_currency: Optional[str] = Field(
+        description="The currency in which the balance sheet is reported.",
+        default=None,
+    )
+    net_income_continuing_operations: Optional[float] = Field(
+        default=None, description="Net Income (Continuing Operations)"
+    )
+    net_income_discontinued_operations: Optional[float] = Field(
+        default=None, description="Net Income (Discontinued Operations)"
+    )
     net_income: Optional[float] = Field(
         default=None, description="Consolidated Net Income."
     )
@@ -114,12 +135,6 @@ class IntrinioCashFlowStatementData(CashFlowStatementData):
     net_cash_from_discontinued_operating_activities: Optional[float] = Field(
         default=None, description="Net Cash from Discontinued Operating Activities"
     )
-    net_income_continuing_operations: Optional[float] = Field(
-        default=None, description="Net Income (Continuing Operations)"
-    )
-    net_income_discontinued_operations: Optional[float] = Field(
-        default=None, description="Net Income (Discontinued Operations)"
-    )
     net_cash_from_operating_activities: Optional[float] = Field(
         default=None, description="Net Cash from Operating Activities"
     )
@@ -215,9 +230,13 @@ class IntrinioCashFlowStatementData(CashFlowStatementData):
 
     @model_validator(mode="before")
     @classmethod
-    def replace_zero(cls, values):  # pylint: disable=no-self-argument
+    def replace_zero(cls, values):
         """Check for zero values and replace with None."""
-        return {k: None if v == 0 else v for k, v in values.items()}
+        return (
+            {k: None if v == 0 else v for k, v in values.items()}
+            if isinstance(values, dict)
+            else values
+        )
 
 
 class IntrinioCashFlowStatementFetcher(
@@ -240,13 +259,14 @@ class IntrinioCashFlowStatementFetcher(
         **kwargs: Any,
     ) -> List[Dict]:
         """Return the raw data from the Intrinio endpoint."""
-
         api_key = credentials.get("intrinio_api_key") if credentials else ""
         statement_code = "cash_flow_statement"
         if query.period in ["quarter", "annual"]:
             period_type = "FY" if query.period == "annual" else "QTR"
-        if query.period in ["ttm", "ytd"]:
+        elif query.period in ["ttm", "ytd"]:
             period_type = query.period.upper()
+        else:
+            raise OpenBBError(f"Period '{query.period}' not supported.")
 
         base_url = "https://api-v2.intrinio.com"
         fundamentals_url = (
@@ -255,7 +275,7 @@ class IntrinioCashFlowStatementFetcher(
         )
         if query.fiscal_year is not None:
             if query.fiscal_year < 2008:
-                _warn("Financials data is only available from 2008 and later.")
+                warn("Financials data is only available from 2008 and later.")
                 query.fiscal_year = 2008
             fundamentals_url = fundamentals_url + f"&fiscal_year={query.fiscal_year}"
         fundamentals_url = fundamentals_url + f"&api_key={api_key}"
@@ -273,10 +293,10 @@ class IntrinioCashFlowStatementFetcher(
             """Return the response."""
             statement_data = await response.json()
             return {
-                "period_ending": statement_data["fundamental"]["end_date"],
-                "fiscal_period": statement_data["fundamental"]["fiscal_period"],
-                "fiscal_year": statement_data["fundamental"]["fiscal_year"],
-                "financials": statement_data["standardized_financials"],
+                "period_ending": statement_data["fundamental"]["end_date"],  # type: ignore
+                "fiscal_period": statement_data["fundamental"]["fiscal_period"],  # type: ignore
+                "fiscal_year": statement_data["fundamental"]["fiscal_year"],  # type: ignore
+                "financials": statement_data["standardized_financials"],  # type: ignore
             }
 
         intrinio_id = f"{query.symbol}-{statement_code}"
@@ -293,10 +313,14 @@ class IntrinioCashFlowStatementFetcher(
     ) -> List[IntrinioCashFlowStatementData]:
         """Return the transformed data."""
         transformed_data: List[IntrinioCashFlowStatementData] = []
+        units = []
         for item in data:
             sub_dict: Dict[str, Any] = {}
 
             for sub_item in item["financials"]:
+                unit = sub_item["data_tag"].get("unit", "")
+                if unit and len(unit) == 3:
+                    units.append(unit)
                 field_name = sub_item["data_tag"]["tag"]
                 sub_dict[field_name] = (
                     float(sub_item["value"])
@@ -307,6 +331,7 @@ class IntrinioCashFlowStatementFetcher(
             sub_dict["period_ending"] = item["period_ending"]
             sub_dict["fiscal_year"] = item["fiscal_year"]
             sub_dict["fiscal_period"] = item["fiscal_period"]
+            sub_dict["reported_currency"] = list(set(units))[0]
 
             transformed_data.append(IntrinioCashFlowStatementData(**sub_dict))
 
