@@ -1,13 +1,17 @@
 """Intrinio Income Statement Model."""
 
-import warnings
-from typing import Any, Dict, List, Literal, Optional
+# pylint: disable=unused-argument
 
+from typing import Any, Dict, List, Literal, Optional
+from warnings import warn
+
+from openbb_core.app.model.abstract.error import OpenBBError
 from openbb_core.provider.abstract.fetcher import Fetcher
 from openbb_core.provider.standard_models.income_statement import (
     IncomeStatementData,
     IncomeStatementQueryParams,
 )
+from openbb_core.provider.utils.descriptions import QUERY_DESCRIPTIONS
 from openbb_core.provider.utils.helpers import (
     ClientResponse,
     ClientSession,
@@ -16,8 +20,6 @@ from openbb_core.provider.utils.helpers import (
 from openbb_intrinio.utils.helpers import get_data_one
 from pydantic import Field, field_validator
 
-_warn = warnings.warn
-
 
 class IntrinioIncomeStatementQueryParams(IncomeStatementQueryParams):
     """Intrinio Income Statement Query.
@@ -26,7 +28,16 @@ class IntrinioIncomeStatementQueryParams(IncomeStatementQueryParams):
     Source: https://docs.intrinio.com/documentation/web_api/get_fundamental_standardized_financials_v2
     """
 
-    period: Literal["annual", "quarter", "ttm", "ytd"] = Field(default="annual")
+    __json_schema_extra__ = {
+        "period": {
+            "choices": ["annual", "quarter", "ttm", "ytd"],
+        }
+    }
+
+    period: Literal["annual", "quarter", "ttm", "ytd"] = Field(
+        default="annual",
+        description=QUERY_DESCRIPTIONS.get("period", ""),
+    )
     fiscal_year: Optional[int] = Field(
         default=None,
         description="The specific fiscal year.  Reports do not go beyond 2008.",
@@ -104,7 +115,7 @@ class IntrinioIncomeStatementData(IncomeStatementData):
         "short_term_borrowings_interest_expense": "shorttermborrowinginterestexpense",
         "cost_of_revenue": "totalcostofrevenue",
         "gross_profit": "totalgrossprofit",
-        "gross_profit_ratio": "grossmargin",
+        "gross_profit_margin": "grossmargin",
         "total_interest_expense": "totalinterestexpense",
         "interest_and_investment_income": "totalinterestincome",
         "total_non_interest_expense": "totalnoninterestexpense",
@@ -124,6 +135,10 @@ class IntrinioIncomeStatementData(IncomeStatementData):
         "weighted_average_diluted_shares_outstanding": "weightedavedilutedsharesos",
     }
 
+    reported_currency: Optional[str] = Field(
+        description="The currency in which the balance sheet is reported.",
+        default=None,
+    )
     revenue: Optional[float] = Field(default=None, description="Total revenue")
     operating_revenue: Optional[float] = Field(
         default=None, description="Total operating revenue"
@@ -137,8 +152,10 @@ class IntrinioIncomeStatementData(IncomeStatementData):
     gross_profit: Optional[float] = Field(
         default=None, description="Total gross profit"
     )
-    gross_profit_ratio: Optional[float] = Field(
-        default=None, description="Gross margin ratio."
+    gross_profit_margin: Optional[float] = Field(
+        default=None,
+        description="Gross margin ratio.",
+        json_schema_extra={"x-unit_measurement": "percent", "x-frontend_multiply": 100},
     )
     provision_for_credit_losses: Optional[float] = Field(
         default=None,
@@ -221,11 +238,11 @@ class IntrinioIncomeStatementData(IncomeStatementData):
     deposits_interest_expense: Optional[float] = Field(
         default=None, description="Deposits interest expense"
     )
-    federal_funds_purchased_and_securities_sold_interest_expense: Optional[
-        float
-    ] = Field(
-        default=None,
-        description="Federal funds purchased and securities sold interest expense",
+    federal_funds_purchased_and_securities_sold_interest_expense: Optional[float] = (
+        Field(
+            default=None,
+            description="Federal funds purchased and securities sold interest expense",
+        )
     )
     other_interest_expense: Optional[float] = Field(
         default=None, description="Other interest expense"
@@ -284,6 +301,7 @@ class IntrinioIncomeStatementData(IncomeStatementData):
     ebitda_margin: Optional[float] = Field(
         default=None,
         description="Margin on Earnings Before Interest, Taxes, Depreciation and Amortization.",
+        json_schema_extra={"x-unit_measurement": "percent", "x-frontend_multiply": 100},
     )
     total_pre_tax_income: Optional[float] = Field(
         default=None, description="Total pre-tax income"
@@ -292,7 +310,9 @@ class IntrinioIncomeStatementData(IncomeStatementData):
         default=None, description="Earnings Before Interest and Taxes."
     )
     pre_tax_income_margin: Optional[float] = Field(
-        default=None, description="Pre-Tax Income Margin."
+        default=None,
+        description="Pre-Tax Income Margin.",
+        json_schema_extra={"x-unit_measurement": "percent", "x-frontend_multiply": 100},
     )
     income_tax_expense: Optional[float] = Field(
         default=None, description="Income tax expense"
@@ -390,8 +410,11 @@ class IntrinioIncomeStatementFetcher(
         statement_code = "income_statement"
         if query.period in ["quarter", "annual"]:
             period_type = "FY" if query.period == "annual" else "QTR"
-        if query.period in ["ttm", "ytd"]:
+        elif query.period in ["ttm", "ytd"]:
             period_type = query.period.upper()
+        else:
+            raise OpenBBError(f"Period '{query.period}' not supported.")
+
         data_tags = [
             "ebit",
             "ebitda",
@@ -410,7 +433,7 @@ class IntrinioIncomeStatementFetcher(
         )
         if query.fiscal_year is not None:
             if query.fiscal_year < 2008:
-                _warn("Financials data is only available from 2008 and later.")
+                warn("Financials data is only available from 2008 and later.")
                 query.fiscal_year = 2008
             fundamentals_url = fundamentals_url + f"&fiscal_year={query.fiscal_year}"
         fundamentals_url = fundamentals_url + f"&api_key={api_key}"
@@ -435,15 +458,15 @@ class IntrinioIncomeStatementFetcher(
 
             calculations_data = [
                 item
-                for item in calculations_data.get("standardized_financials", [])
+                for item in calculations_data.get("standardized_financials", [])  # type: ignore
                 if item["data_tag"]["tag"] in data_tags
             ]
 
             return {
-                "period_ending": statement_data["fundamental"]["end_date"],
-                "fiscal_period": statement_data["fundamental"]["fiscal_period"],
-                "fiscal_year": statement_data["fundamental"]["fiscal_year"],
-                "financials": statement_data["standardized_financials"]
+                "period_ending": statement_data["fundamental"]["end_date"],  # type: ignore
+                "fiscal_period": statement_data["fundamental"]["fiscal_period"],  # type: ignore
+                "fiscal_year": statement_data["fundamental"]["fiscal_year"],  # type: ignore
+                "financials": statement_data["standardized_financials"]  # type: ignore
                 + calculations_data,
             }
 
@@ -461,11 +484,14 @@ class IntrinioIncomeStatementFetcher(
     ) -> List[IntrinioIncomeStatementData]:
         """Return the transformed data."""
         transformed_data: List[IntrinioIncomeStatementData] = []
-
+        units = []
         for item in data:
             sub_dict: Dict[str, Any] = {}
 
             for sub_item in item["financials"]:
+                unit = sub_item["data_tag"].get("unit", "")
+                if unit and len(unit) == 3:
+                    units.append(unit)
                 field_name = sub_item["data_tag"]["tag"]
                 sub_dict[field_name] = (
                     float(sub_item["value"])
@@ -476,6 +502,7 @@ class IntrinioIncomeStatementFetcher(
             sub_dict["period_ending"] = item["period_ending"]
             sub_dict["fiscal_year"] = item["fiscal_year"]
             sub_dict["fiscal_period"] = item["fiscal_period"]
+            sub_dict["reported_currency"] = list(set(units))[0]
 
             transformed_data.append(IntrinioIncomeStatementData(**sub_dict))
 
