@@ -9,7 +9,8 @@ from datetime import (
 from io import StringIO
 from typing import Any, Dict, List, Optional, TypeVar, Union
 
-from openbb_core.provider.utils.errors import EmptyDataError
+from openbb_core.app.model.abstract.error import OpenBBError
+from openbb_core.provider.utils.errors import EmptyDataError, UnauthorizedError
 from openbb_core.provider.utils.helpers import (
     ClientResponse,
     ClientSession,
@@ -59,15 +60,17 @@ def request(url: str) -> BasicResponse:
 async def response_callback(
     response: ClientResponse, _: ClientSession
 ) -> Union[dict, List[dict]]:
-    """Callback for async_request."""
+    """Use callback for async_request."""
     data = await response.json()
 
-    if isinstance(data, dict) and response.status != 200:
+    if isinstance(data, dict) and (response.status != 200 or data.get("error")):
         if message := data.get("error", None) or data.get("message", None):
-            raise RuntimeError(f"Error in Intrinio request -> {message}")
+            if "api key" in message.lower():
+                raise UnauthorizedError(f"Unauthorized Intrinio request -> {message}")
+            raise OpenBBError(f"Error in Intrinio request -> {message}")
 
         if error := data.get("Error Message", None):
-            raise RuntimeError(f"Intrinio Error Message -> {error}")
+            raise OpenBBError(f"Intrinio Error Message -> {error}")
 
     if isinstance(data, (str, float)):
         data = {"value": data}
@@ -123,11 +126,11 @@ async def get_data_one(url: str, **kwargs: Any) -> Dict[str, Any]:
     return data
 
 
-def get_weekday(date: dateType) -> str:
+def get_weekday(date: dateType) -> dateType:
     """Return the weekday date."""
     if date.weekday() in [5, 6]:
-        return (date - timedelta(days=date.weekday() - 4)).strftime("%Y-%m-%d")
-    return date.strftime("%Y-%m-%d")
+        return date - timedelta(days=date.weekday() - 4)
+    return date
 
 
 async def async_get_data_one(
